## 0.3.0 (2025-03-04)

### Feat

- add scheduler script
- add holiday detection and asynchronous publishing

## 0.2.1 (2025-03-01)

### Refactor

- add license and package metadata

## 0.2.0 (2025-03-01)

### Feat

- add Slack integration

### Fix

- update date retrieval to use timezone-aware current date

### Refactor

- improve slack message format
- expand __all__ exports in module to include additional classes and errors
- split into submodule

## 0.1.0 (2025-01-03)

### Feat

- initial commit

### Refactor

- use src-layout and add build configs
